import re
from skimage.io import imread, imsave

def ler_imagem(caminho, e_cinza = False):
    imagem = imread(caminho, as_gray = e_cinza)
    return imagem

def salvar_imagem(imagem, caminho):
    imsave(caminho, imagem)


import numpy as np
from skimage.color import rgb2gray
from skimage.exposure import match_histograms
from skimage.metrics import structural_similarity

def encontrar_diferenca(imagem1, imagem2):
    assert imagem1.shape == imagem2.shape, "Especifique 2 imagens de mesmo formato."
    imagem1_cinza = rgb2gray(imagem1)
    imagem2_cinza = rgb2gray(imagem2)
    (score, diferenca_imagem) = structural_similarity(imagem1_cinza, imagem2_cinza, full=True)
    print("Similaridade das imagens:", score)
    diferenca_imagem_normalizada =(diferenca_imagem-np.min(diferenca_imagem))/(np.max(diferenca_imagem)-np.min(diferenca_imagem))
    return diferenca_imagem_normalizada

def transferir_histograma(imagem1, imagem2):
    imagem_combinada = match_histograms(imagem1, imagem2, multichannel=True)
    return imagem_combinada


import matplotlib.pyplot as plt

def plotar_imagem(imagem):
    plt.figure(figsize=(12, 4))
    plt.imshow(imagem, cmap='gray')
    plt.axis('off')
    plt.show()

def plotar_resultado(*args):
    numero_imagens = len(args)
    fig, axis = plt.subplots(nrows=1, ncols = numero_imagens, figsize=(12, 4))
    lista_nomes = ['imagem {}'.format(i) for i in range(1, numero_imagens)]
    lista_nomes.append('Resultado')
    for ax, nome, imagem in zip(axis, lista_nomes, args):
        ax.set_title(nome)
        ax.imshow(imagem, cmap='gray')
        ax.axis('off')
    fig.tight_layout()
    plt.show()
    
def plotar_histograma(imagem):
    fig, axis = plt.subplots(nrows = 1, ncols = 3, figsize = (12, 4), sharex=True, sharey=True)
    lista_cores = ['red', 'green', 'blue']
    for index, (ax, color) in enumerate(zip(axis, lista_cores)):
        ax.set_title('{} histograma'.format(color.title()))
        ax.hist(imagem[:, :, index].ravel(), bins = 256, color = color, alpha = 0.8)
    fig.tight_layout()
    plt.show()


from skimage.transform import resize

def redimensionar_imagem(imagem, proporcao):
    assert 0 <= proporcao <= 1, "Especifique uma proporção valida entre 0 e 1."
    altura = round(imagem.shape[0] * proporcao)
    largura = round(imagem.shape[1] * proporcao)
    imagem_redimencionada = resize(imagem, (altura, largura), anti_aliasing=True)
    return imagem_redimencionada